@@ -1,23 +1,36 @@
 from sqlalchemy import create_engine, orm
 from sqlalchemy.ext.declarative import declarative_base
+import os
 
 from ..config import database_cfg
 
 __all__ = ('Base', 'engine', 'session', 'DB_FILENAME', 'init_tables')
 
+
+def _try_get_env(value: str):
+    if value.lower().startswith('env_'):
+        if value[4:] not in os.environ:
+            print('----------DATABASE ERROR----------')
+            print(f'missing environment variable/key: {value[4:]}')
+            input('\npress enter to exit...')
+            exit(1)
+        return os.environ[value[4:]]
+    return value
+
+
 Base = declarative_base()
 DB_FILENAME = 'database.sqlite'
 try:
     engine = create_engine(f'sqlite:///{DB_FILENAME}'
                            if not database_cfg.enabled else
                            database_cfg.connection.format(
-                               database_format=database_cfg.database_format,
-                               driver=database_cfg.driver,
-                               username=database_cfg.username,
-                               password=database_cfg.password,
-                               address=database_cfg.address,
-                               port=database_cfg.port,
-                               database=database_cfg.database
+                               database_format=_try_get_env(database_cfg.database_format),
+                               driver=_try_get_env(database_cfg.driver),
+                               username=_try_get_env(database_cfg.username),
+                               password=_try_get_env(database_cfg.password),
+                               address=_try_get_env(database_cfg.address),
+                               port=_try_get_env(database_cfg.port),
+                               database=_try_get_env(database_cfg.database)
                            ))
 except (ImportError, ModuleNotFoundError):
     print(
